"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.mdb.greenplum.v1.backup_pb2
import yandex.cloud.mdb.greenplum.v1.cluster_pb2
import yandex.cloud.mdb.greenplum.v1.config_pb2
import yandex.cloud.mdb.greenplum.v1.host_pb2
import yandex.cloud.mdb.greenplum.v1.maintenance_pb2
import yandex.cloud.mdb.greenplum.v1.pxf_pb2
import yandex.cloud.operation.operation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster resource to return.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list Greenplum® clusters in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClustersResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClustersResponse.next_page_token] returned by the previous list request."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:

    1. The field name. Currently you can only use filtering with the [Cluster.name] field.

    2. An `=` operator.

    3. The value in double quotes (`"`). Must be 1-63 characters long and match the regular expression `[a-zA-Z0-9_-]+`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClustersRequest.page_size], use the [next_page_token] as the value for the [ListClustersRequest.page_token] parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.greenplum.v1.cluster_pb2.Cluster]:
        """List of Greenplum® cluster resources."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.mdb.greenplum.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    MASTER_CONFIG_FIELD_NUMBER: builtins.int
    SEGMENT_CONFIG_FIELD_NUMBER: builtins.int
    MASTER_HOST_COUNT_FIELD_NUMBER: builtins.int
    SEGMENT_IN_HOST_FIELD_NUMBER: builtins.int
    SEGMENT_HOST_COUNT_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    USER_PASSWORD_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    CLOUD_STORAGE_FIELD_NUMBER: builtins.int
    MASTER_HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    SEGMENT_HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create the Greenplum® cluster in."""
    name: builtins.str
    """Name of the Greenplum® cluster. The name must be unique within the folder."""
    description: builtins.str
    """Description of the Greenplum® cluster."""
    environment: yandex.cloud.mdb.greenplum.v1.cluster_pb2.Cluster.Environment.ValueType
    """Deployment environment of the Greenplum® cluster."""
    master_host_count: builtins.int
    """Number of hosts in the master subcluster."""
    segment_in_host: builtins.int
    """Number of segments per host."""
    segment_host_count: builtins.int
    """Number of hosts in the segment subcluster."""
    user_name: builtins.str
    """Owner user name."""
    user_password: builtins.str
    """Owner user password."""
    network_id: builtins.str
    """ID of the network to create the cluster in."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    service_account_id: builtins.str
    """ID of the service account used for access Yandex Cloud resources."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Greenplum® cluster as `key:value` pairs.
        For example, `"project":"mvp"` or `"source":"dictionary"`.
        """

    @property
    def config(self) -> yandex.cloud.mdb.greenplum.v1.cluster_pb2.GreenplumConfig:
        """Greenplum® cluster configuration."""

    @property
    def master_config(self) -> global___MasterSubclusterConfigSpec:
        """Configuration of the Greenplum® master subcluster."""

    @property
    def segment_config(self) -> global___SegmentSubclusterConfigSpec:
        """Configuration of the Greenplum® segment subcluster."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups to place VMs of the cluster in."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceWindow:
        """A Greenplum® cluster maintenance window. Should be defined by either one of the two options."""

    @property
    def config_spec(self) -> global___ConfigSpec:
        """Configuration of Greenplum® and Odyssey®."""

    @property
    def cloud_storage(self) -> yandex.cloud.mdb.greenplum.v1.cluster_pb2.CloudStorage:
        """Cloud storage settings"""

    @property
    def master_host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the master subcluster."""

    @property
    def segment_host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the segment subcluster."""

    @property
    def logging(self) -> yandex.cloud.mdb.greenplum.v1.cluster_pb2.LoggingConfig:
        """Cloud logging configuration"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: yandex.cloud.mdb.greenplum.v1.cluster_pb2.Cluster.Environment.ValueType = ...,
        config: yandex.cloud.mdb.greenplum.v1.cluster_pb2.GreenplumConfig | None = ...,
        master_config: global___MasterSubclusterConfigSpec | None = ...,
        segment_config: global___SegmentSubclusterConfigSpec | None = ...,
        master_host_count: builtins.int = ...,
        segment_in_host: builtins.int = ...,
        segment_host_count: builtins.int = ...,
        user_name: builtins.str = ...,
        user_password: builtins.str = ...,
        network_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        maintenance_window: yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        config_spec: global___ConfigSpec | None = ...,
        cloud_storage: yandex.cloud.mdb.greenplum.v1.cluster_pb2.CloudStorage | None = ...,
        master_host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        segment_host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        logging: yandex.cloud.mdb.greenplum.v1.cluster_pb2.LoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_storage", b"cloud_storage", "config", b"config", "config_spec", b"config_spec", "logging", b"logging", "maintenance_window", b"maintenance_window", "master_config", b"master_config", "segment_config", b"segment_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_storage", b"cloud_storage", "config", b"config", "config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "host_group_ids", b"host_group_ids", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "master_config", b"master_config", "master_host_count", b"master_host_count", "master_host_group_ids", b"master_host_group_ids", "name", b"name", "network_id", b"network_id", "security_group_ids", b"security_group_ids", "segment_config", b"segment_config", "segment_host_count", b"segment_host_count", "segment_host_group_ids", b"segment_host_group_ids", "segment_in_host", b"segment_in_host", "service_account_id", b"service_account_id", "user_name", b"user_name", "user_password", b"user_password"]) -> None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class ConfigSpec(google.protobuf.message.Message):
    """Configuration of Greenplum® and Odyssey®."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GREENPLUM_CONFIG_6_17_FIELD_NUMBER: builtins.int
    GREENPLUM_CONFIG_6_19_FIELD_NUMBER: builtins.int
    GREENPLUM_CONFIG_6_21_FIELD_NUMBER: builtins.int
    GREENPLUM_CONFIG_6_22_FIELD_NUMBER: builtins.int
    GREENPLUM_CONFIG_6_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    BACKGROUND_ACTIVITIES_FIELD_NUMBER: builtins.int
    PXF_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def greenplum_config_6_17(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6_17: ...
    @property
    def greenplum_config_6_19(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6_19: ...
    @property
    def greenplum_config_6_21(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6_21: ...
    @property
    def greenplum_config_6_22(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6_22: ...
    @property
    def greenplum_config_6(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6: ...
    @property
    def pool(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.ConnectionPoolerConfig:
        """Odyssey® pool settings."""

    @property
    def background_activities(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.BackgroundActivitiesConfig:
        """Managed Greenplum® background tasks configuration."""

    @property
    def pxf_config(self) -> yandex.cloud.mdb.greenplum.v1.pxf_pb2.PXFConfig: ...
    def __init__(
        self,
        *,
        greenplum_config_6_17: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6_17 | None = ...,
        greenplum_config_6_19: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6_19 | None = ...,
        greenplum_config_6_21: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6_21 | None = ...,
        greenplum_config_6_22: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6_22 | None = ...,
        greenplum_config_6: yandex.cloud.mdb.greenplum.v1.config_pb2.GreenplumConfig6 | None = ...,
        pool: yandex.cloud.mdb.greenplum.v1.config_pb2.ConnectionPoolerConfig | None = ...,
        background_activities: yandex.cloud.mdb.greenplum.v1.config_pb2.BackgroundActivitiesConfig | None = ...,
        pxf_config: yandex.cloud.mdb.greenplum.v1.pxf_pb2.PXFConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["background_activities", b"background_activities", "greenplum_config", b"greenplum_config", "greenplum_config_6", b"greenplum_config_6", "greenplum_config_6_17", b"greenplum_config_6_17", "greenplum_config_6_19", b"greenplum_config_6_19", "greenplum_config_6_21", b"greenplum_config_6_21", "greenplum_config_6_22", b"greenplum_config_6_22", "pool", b"pool", "pxf_config", b"pxf_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["background_activities", b"background_activities", "greenplum_config", b"greenplum_config", "greenplum_config_6", b"greenplum_config_6", "greenplum_config_6_17", b"greenplum_config_6_17", "greenplum_config_6_19", b"greenplum_config_6_19", "greenplum_config_6_21", b"greenplum_config_6_21", "greenplum_config_6_22", b"greenplum_config_6_22", "pool", b"pool", "pxf_config", b"pxf_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["greenplum_config", b"greenplum_config"]) -> typing.Literal["greenplum_config_6_17", "greenplum_config_6_19", "greenplum_config_6_21", "greenplum_config_6_22", "greenplum_config_6"] | None: ...

global___ConfigSpec = ConfigSpec

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    MASTER_CONFIG_FIELD_NUMBER: builtins.int
    SEGMENT_CONFIG_FIELD_NUMBER: builtins.int
    USER_PASSWORD_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    CONFIG_SPEC_FIELD_NUMBER: builtins.int
    CLOUD_STORAGE_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster resource to update.
    To get the Greenplum® cluster ID, use a [ClusterService.List] request.
    """
    description: builtins.str
    """New description of the Greenplum® cluster."""
    name: builtins.str
    """New name for the cluster."""
    user_password: builtins.str
    """Owner user password."""
    network_id: builtins.str
    """ID of the network to move the cluster to."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    service_account_id: builtins.str
    """ID of the service account used for access YC resources."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Greenplum® cluster resource should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Greenplum® cluster as `key:value` pairs.
        For example, `"project":"mvp"` or `"source":"dictionary"`.

        The new set of labels completely replaces the old one.
        To add a label, request the current set with the [ClusterService.Get] method, then send an [ClusterService.Update] request with the new label added to the set.
        """

    @property
    def config(self) -> yandex.cloud.mdb.greenplum.v1.cluster_pb2.GreenplumConfig:
        """The Greenplum® cluster configuration."""

    @property
    def master_config(self) -> global___MasterSubclusterConfigSpec:
        """Configuration of the Greenplum® master subcluster."""

    @property
    def segment_config(self) -> global___SegmentSubclusterConfigSpec:
        """Configuration of the Greenplum® segment subcluster."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceWindow:
        """The Greenplum® cluster maintenance window. Should be defined by either one of the two options."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def config_spec(self) -> global___ConfigSpec:
        """Settings of the Greenplum® cluster."""

    @property
    def cloud_storage(self) -> yandex.cloud.mdb.greenplum.v1.cluster_pb2.CloudStorage:
        """Cloud storage settings"""

    @property
    def logging(self) -> yandex.cloud.mdb.greenplum.v1.cluster_pb2.LoggingConfig:
        """Cloud logging configuration"""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        config: yandex.cloud.mdb.greenplum.v1.cluster_pb2.GreenplumConfig | None = ...,
        master_config: global___MasterSubclusterConfigSpec | None = ...,
        segment_config: global___SegmentSubclusterConfigSpec | None = ...,
        user_password: builtins.str = ...,
        network_id: builtins.str = ...,
        maintenance_window: yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        config_spec: global___ConfigSpec | None = ...,
        cloud_storage: yandex.cloud.mdb.greenplum.v1.cluster_pb2.CloudStorage | None = ...,
        service_account_id: builtins.str = ...,
        logging: yandex.cloud.mdb.greenplum.v1.cluster_pb2.LoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_storage", b"cloud_storage", "config", b"config", "config_spec", b"config_spec", "logging", b"logging", "maintenance_window", b"maintenance_window", "master_config", b"master_config", "segment_config", b"segment_config", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_storage", b"cloud_storage", "cluster_id", b"cluster_id", "config", b"config", "config_spec", b"config_spec", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "master_config", b"master_config", "name", b"name", "network_id", b"network_id", "security_group_ids", b"security_group_ids", "segment_config", b"segment_config", "service_account_id", b"service_account_id", "update_mask", b"update_mask", "user_password", b"user_password"]) -> None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster resource that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class AddClusterHostsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum Cluster resource that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___AddClusterHostsMetadata = AddClusterHostsMetadata

@typing.final
class ExpandRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SEGMENT_HOST_COUNT_FIELD_NUMBER: builtins.int
    ADD_SEGMENTS_PER_HOST_COUNT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    PARALLEL_FIELD_NUMBER: builtins.int
    CLOSE_CLUSTER_FIELD_NUMBER: builtins.int
    DELAY_REDISTRIBUTION_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum Cluster resource to update.
    To get the Greenplum cluster ID, use a [ClusterService.List] request.
    """
    segment_host_count: builtins.int
    """Number of hosts for add to the segment subcluster"""
    add_segments_per_host_count: builtins.int
    """Number of segments per host to add"""
    duration: builtins.int
    """Redistribute duration, in seconds"""
    parallel: builtins.int
    """Redistribute process parallelism, 0 - for automatic detection"""
    close_cluster: builtins.bool
    """Deny all client connections during the expand operation"""
    delay_redistribution: builtins.bool
    """Perform redistribution process by small chunks as background activity"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        segment_host_count: builtins.int = ...,
        add_segments_per_host_count: builtins.int = ...,
        duration: builtins.int = ...,
        parallel: builtins.int = ...,
        close_cluster: builtins.bool = ...,
        delay_redistribution: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["add_segments_per_host_count", b"add_segments_per_host_count", "close_cluster", b"close_cluster", "cluster_id", b"cluster_id", "delay_redistribution", b"delay_redistribution", "duration", b"duration", "parallel", b"parallel", "segment_host_count", b"segment_host_count"]) -> None: ...

global___ExpandRequest = ExpandRequest

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster to delete.
    To get the Greenplum® cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster to start.
    To get the Greenplum® cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster being started."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster to stop.
    To get the Greenplum® cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster being stopped."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata

@typing.final
class MoveClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster to move."""
    destination_folder_id: builtins.str
    """ID of the destination folder."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "destination_folder_id", b"destination_folder_id"]) -> None: ...

global___MoveClusterRequest = MoveClusterRequest

@typing.final
class MoveClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SOURCE_FOLDER_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster being moved."""
    source_folder_id: builtins.str
    """ID of the source folder."""
    destination_folder_id: builtins.str
    """ID of the destination folder."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        source_folder_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "destination_folder_id", b"destination_folder_id", "source_folder_id", b"source_folder_id"]) -> None: ...

global___MoveClusterMetadata = MoveClusterMetadata

@typing.final
class ListClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClusterOperationsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClusterOperationsResponse.next_page_token] returned by the previous list request."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterOperationsRequest = ListClusterOperationsRequest

@typing.final
class ListClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterOperationsRequest.page_size], use the [next_page_token] as the value for the [ListClusterOperationsRequest.page_token] query parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of Operation resources for the specified Greenplum® cluster."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListClusterOperationsResponse = ListClusterOperationsResponse

@typing.final
class ListClusterHostsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster.

    To get the Greenplum® cluster ID use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClusterHostsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClusterHostsResponse.next_page_token] returned by the previous list request."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterHostsRequest = ListClusterHostsRequest

@typing.final
class ListClusterHostsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterHostsRequest.page_size], use the [next_page_token] as the value for the [ListClusterHostsRequest.page_token] query parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.greenplum.v1.host_pb2.Host]:
        """Requested list of hosts for the cluster."""

    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[yandex.cloud.mdb.greenplum.v1.host_pb2.Host] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterHostsResponse = ListClusterHostsResponse

@typing.final
class MasterSubclusterConfigSpec(google.protobuf.message.Message):
    """Configuration of the master subcluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.Resources:
        """Resources allocated to Greenplum® master subcluster hosts."""

    def __init__(
        self,
        *,
        resources: yandex.cloud.mdb.greenplum.v1.config_pb2.Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___MasterSubclusterConfigSpec = MasterSubclusterConfigSpec

@typing.final
class SegmentSubclusterConfigSpec(google.protobuf.message.Message):
    """Configuration of the segment subcluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.Resources:
        """Resources allocated to Greenplum® segment subcluster hosts."""

    def __init__(
        self,
        *,
        resources: yandex.cloud.mdb.greenplum.v1.config_pb2.Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___SegmentSubclusterConfigSpec = SegmentSubclusterConfigSpec

@typing.final
class ListClusterLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterLogsRequest.page_size], use the [next_page_token] as the value for the [ListClusterLogsRequest.page_token] query parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.

    This value is interchangeable with the [StreamLogRecord.next_record_token] from [StreamLogs] method.
    """
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogRecord]:
        """Requested log records."""

    def __init__(
        self,
        *,
        logs: collections.abc.Iterable[global___LogRecord] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["logs", b"logs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterLogsResponse = ListClusterLogsResponse

@typing.final
class LogRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MessageEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the log was recorded."""

    @property
    def message(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Contents of the log record."""

    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        message: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "timestamp", b"timestamp"]) -> None: ...

global___LogRecord = LogRecord

@typing.final
class ListClusterLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ServiceType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServiceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ListClusterLogsRequest._ServiceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SERVICE_TYPE_UNSPECIFIED: ListClusterLogsRequest._ServiceType.ValueType  # 0
        """Type is not specified."""
        GREENPLUM: ListClusterLogsRequest._ServiceType.ValueType  # 1
        """Greenplum® activity logs."""
        GREENPLUM_POOLER: ListClusterLogsRequest._ServiceType.ValueType  # 2
        """Greenplum® pooler logs."""
        GREENPLUM_PXF: ListClusterLogsRequest._ServiceType.ValueType  # 3
        """Greenplum® PXF service logs."""

    class ServiceType(_ServiceType, metaclass=_ServiceTypeEnumTypeWrapper): ...
    SERVICE_TYPE_UNSPECIFIED: ListClusterLogsRequest.ServiceType.ValueType  # 0
    """Type is not specified."""
    GREENPLUM: ListClusterLogsRequest.ServiceType.ValueType  # 1
    """Greenplum® activity logs."""
    GREENPLUM_POOLER: ListClusterLogsRequest.ServiceType.ValueType  # 2
    """Greenplum® pooler logs."""
    GREENPLUM_PXF: ListClusterLogsRequest.ServiceType.ValueType  # 3
    """Greenplum® PXF service logs."""

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    COLUMN_FILTER_FIELD_NUMBER: builtins.int
    SERVICE_TYPE_FIELD_NUMBER: builtins.int
    FROM_TIME_FIELD_NUMBER: builtins.int
    TO_TIME_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ALWAYS_NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster to request logs for.

    To get the Greenplum® cluster ID, use a [ClusterService.List] request.
    """
    service_type: global___ListClusterLogsRequest.ServiceType.ValueType
    """Type of the service to request logs about."""
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClusterLogsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClusterLogsResponse.next_page_token] returned by the previous list request."""
    always_next_page_token: builtins.bool
    """The service always returns a [ListClusterLogsResponse.next_page_token], even if the current page is empty."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:

    1. A field name. Currently filtering can be applied to the [LogRecord.logs.message.hostname], [LogRecord.logs.message.error_severity] (for `GREENPLUM` service) and [LogRecord.logs.message.level] (for `GREENPLUM_POOLER` service) fields.

    2. A conditional operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.

    3. A value. Must be 1-63 characters long and match the regular expression `^[a-z0-9.-]{1,61}$`.

    Examples of a filter:
    * `message.hostname='node1.db.cloud.yandex.net'`;
    * `message.error_severity IN ("ERROR", "FATAL", "PANIC") AND message.hostname = "node1.db.cloud.yandex.net"`.
    """
    @property
    def column_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Columns from log table to request.
        If no columns are specified, entire log records are returned.
        """

    @property
    def from_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the logs request."""

    @property
    def to_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End timestamp for the logs request."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        column_filter: collections.abc.Iterable[builtins.str] | None = ...,
        service_type: global___ListClusterLogsRequest.ServiceType.ValueType = ...,
        from_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        always_next_page_token: builtins.bool = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_time", b"from_time", "to_time", b"to_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["always_next_page_token", b"always_next_page_token", "cluster_id", b"cluster_id", "column_filter", b"column_filter", "filter", b"filter", "from_time", b"from_time", "page_size", b"page_size", "page_token", b"page_token", "service_type", b"service_type", "to_time", b"to_time"]) -> None: ...

global___ListClusterLogsRequest = ListClusterLogsRequest

@typing.final
class ListClusterBackupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster.

    To get the Greenplum® cluster ID use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListClusterBackupsResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClusterBackupsResponse.next_page_token] returned by the previous list request."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterBackupsRequest = ListClusterBackupsRequest

@typing.final
class StreamLogRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_FIELD_NUMBER: builtins.int
    NEXT_RECORD_TOKEN_FIELD_NUMBER: builtins.int
    next_record_token: builtins.str
    """This token allows you to continue streaming logs starting from the exact same record.

    To do that, specify value of [next_record_token] as the value for [StreamLogs.record_token] parameter in the next [StreamLogs] request.

    This value is interchangeable with [ListLogs.next_page_token] from [ListLogs] method.
    """
    @property
    def record(self) -> global___LogRecord:
        """One of the requested log records."""

    def __init__(
        self,
        *,
        record: global___LogRecord | None = ...,
        next_record_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["record", b"record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["next_record_token", b"next_record_token", "record", b"record"]) -> None: ...

global___StreamLogRecord = StreamLogRecord

@typing.final
class StreamClusterLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ServiceType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServiceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StreamClusterLogsRequest._ServiceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SERVICE_TYPE_UNSPECIFIED: StreamClusterLogsRequest._ServiceType.ValueType  # 0
        """Type is not specified."""
        GREENPLUM: StreamClusterLogsRequest._ServiceType.ValueType  # 1
        """Greenplum® activity logs."""
        GREENPLUM_POOLER: StreamClusterLogsRequest._ServiceType.ValueType  # 2
        """Greenplum® pooler logs."""
        GREENPLUM_PXF: StreamClusterLogsRequest._ServiceType.ValueType  # 3
        """Greenplum® PXF service logs."""

    class ServiceType(_ServiceType, metaclass=_ServiceTypeEnumTypeWrapper): ...
    SERVICE_TYPE_UNSPECIFIED: StreamClusterLogsRequest.ServiceType.ValueType  # 0
    """Type is not specified."""
    GREENPLUM: StreamClusterLogsRequest.ServiceType.ValueType  # 1
    """Greenplum® activity logs."""
    GREENPLUM_POOLER: StreamClusterLogsRequest.ServiceType.ValueType  # 2
    """Greenplum® pooler logs."""
    GREENPLUM_PXF: StreamClusterLogsRequest.ServiceType.ValueType  # 3
    """Greenplum® PXF service logs."""

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    COLUMN_FILTER_FIELD_NUMBER: builtins.int
    SERVICE_TYPE_FIELD_NUMBER: builtins.int
    FROM_TIME_FIELD_NUMBER: builtins.int
    TO_TIME_FIELD_NUMBER: builtins.int
    RECORD_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum® cluster."""
    service_type: global___StreamClusterLogsRequest.ServiceType.ValueType
    """Type of the service to request logs about."""
    record_token: builtins.str
    """Record token. Set [record_token] to the [StreamLogs.next_record_token] returned by the previous [StreamLogs] request to start streaming from the next log record."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:

    1. A field name. Currently filtering can be applied to the [LogRecord.logs.message.hostname], [LogRecord.logs.message.error_severity] (for GREENPLUM service), [LogRecord.logs.message.level] (for POOLER service) fields.

    2. An `=` operator.

    3. A value in double quotes (`"`). Must be 1-63 characters long and match the regular expression `[a-z0-9.-]{1,61}`.

    Examples of a filter:

    * `message.hostname='node1.db.cloud.yandex.net'`;
    * `message.error_severity IN ("ERROR", "FATAL", "PANIC") AND message.hostname = "node1.db.cloud.yandex.net"`.
    """
    @property
    def column_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Columns from log table to get in the response.
        If no columns are specified, entire log records are returned.
        """

    @property
    def from_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the logs request."""

    @property
    def to_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End timestamp for the logs request.

        If this field is not set, all existing logs are sent as well as the new ones as they appear.

        In essence it has `tail -f` semantics.
        """

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        column_filter: collections.abc.Iterable[builtins.str] | None = ...,
        service_type: global___StreamClusterLogsRequest.ServiceType.ValueType = ...,
        from_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        to_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        record_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_time", b"from_time", "to_time", b"to_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "column_filter", b"column_filter", "filter", b"filter", "from_time", b"from_time", "record_token", b"record_token", "service_type", b"service_type", "to_time", b"to_time"]) -> None: ...

global___StreamClusterLogsRequest = StreamClusterLogsRequest

@typing.final
class ListClusterBackupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests.

    If the number of results is larger than [ListClusterBackupsRequest.page_size], use the [next_page_token] as the value for the [ListClusterBackupsRequest.page_token] query parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def backups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.greenplum.v1.backup_pb2.Backup]:
        """List of Greenplum® backups."""

    def __init__(
        self,
        *,
        backups: collections.abc.Iterable[yandex.cloud.mdb.greenplum.v1.backup_pb2.Backup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backups", b"backups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterBackupsResponse = ListClusterBackupsResponse

@typing.final
class BackupClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster to back up.
    To get the Greenplum cluster ID, use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___BackupClusterRequest = BackupClusterRequest

@typing.final
class BackupClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster to back up."""
    backup_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "cluster_id", b"cluster_id"]) -> None: ...

global___BackupClusterMetadata = BackupClusterMetadata

@typing.final
class RestoreClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BACKUP_ID_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    MASTER_RESOURCES_FIELD_NUMBER: builtins.int
    SEGMENT_RESOURCES_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    SEGMENT_HOST_COUNT_FIELD_NUMBER: builtins.int
    SEGMENT_IN_HOST_FIELD_NUMBER: builtins.int
    RESTORE_ONLY_FIELD_NUMBER: builtins.int
    MASTER_HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    SEGMENT_HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    """ID of the backup to create a cluster from.

    To get the backup ID, use a [ClusterService.ListBackups] request.
    """
    folder_id: builtins.str
    """ID of the folder to create the Greenplum® cluster in."""
    name: builtins.str
    """Name of the Greenplum® cluster. The name must be unique within the folder."""
    description: builtins.str
    """Description of the Greenplum® cluster."""
    environment: yandex.cloud.mdb.greenplum.v1.cluster_pb2.Cluster.Environment.ValueType
    """Deployment environment of the Greenplum® cluster."""
    network_id: builtins.str
    """ID of the network to create the cluster in."""
    deletion_protection: builtins.bool
    """Determines whether the cluster is protected from being deleted."""
    placement_group_id: builtins.str
    """ID of the placement group."""
    segment_host_count: builtins.int
    """Number of segment hosts"""
    segment_in_host: builtins.int
    """Number of segments on each host"""
    service_account_id: builtins.str
    """Service account that will be used to access a Yandex Cloud resources"""
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the moment to which the Greenplum cluster should be restored."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Greenplum® cluster as `key:value` pairs.
        For example, "project":"mvp" or "source":"dictionary".
        """

    @property
    def config(self) -> yandex.cloud.mdb.greenplum.v1.cluster_pb2.GreenplumRestoreConfig:
        """Greenplum® cluster config."""

    @property
    def master_resources(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.Resources:
        """Resources of the Greenplum® master subcluster."""

    @property
    def segment_resources(self) -> yandex.cloud.mdb.greenplum.v1.config_pb2.Resources:
        """Resources of the Greenplum® segment subcluster."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups to place VMs of cluster on."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceWindow:
        """A Greenplum® cluster maintenance window. Should be defined by either one of the two options."""

    @property
    def restore_only(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of databases and tables to restore"""

    @property
    def master_host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the master subcluster."""

    @property
    def segment_host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the segment subcluster."""

    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: yandex.cloud.mdb.greenplum.v1.cluster_pb2.Cluster.Environment.ValueType = ...,
        config: yandex.cloud.mdb.greenplum.v1.cluster_pb2.GreenplumRestoreConfig | None = ...,
        master_resources: yandex.cloud.mdb.greenplum.v1.config_pb2.Resources | None = ...,
        segment_resources: yandex.cloud.mdb.greenplum.v1.config_pb2.Resources | None = ...,
        network_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        placement_group_id: builtins.str = ...,
        maintenance_window: yandex.cloud.mdb.greenplum.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        segment_host_count: builtins.int = ...,
        segment_in_host: builtins.int = ...,
        restore_only: collections.abc.Iterable[builtins.str] | None = ...,
        master_host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        segment_host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "maintenance_window", b"maintenance_window", "master_resources", b"master_resources", "segment_resources", b"segment_resources", "time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "config", b"config", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "host_group_ids", b"host_group_ids", "labels", b"labels", "maintenance_window", b"maintenance_window", "master_host_group_ids", b"master_host_group_ids", "master_resources", b"master_resources", "name", b"name", "network_id", b"network_id", "placement_group_id", b"placement_group_id", "restore_only", b"restore_only", "security_group_ids", b"security_group_ids", "segment_host_count", b"segment_host_count", "segment_host_group_ids", b"segment_host_group_ids", "segment_in_host", b"segment_in_host", "segment_resources", b"segment_resources", "service_account_id", b"service_account_id", "time", b"time"]) -> None: ...

global___RestoreClusterRequest = RestoreClusterRequest

@typing.final
class RestoreClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the new Greenplum® cluster that is being created from a backup."""
    backup_id: builtins.str
    """ID of the backup that is being used for creating a cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "cluster_id", b"cluster_id"]) -> None: ...

global___RestoreClusterMetadata = RestoreClusterMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/backup/v1/backup_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/backup/v1/backup_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.backup.v1 import backup_pb2 as yandex_dot_cloud_dot_backup_dot_v1_dot_backup__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.backup.v1 import resource_pb2 as yandex_dot_cloud_dot_backup_dot_v1_dot_resource__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/backup/v1/backup_service.proto\x12\x16yandex.cloud.backup.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a#yandex/cloud/backup/v1/backup.proto\x1a&yandex/cloud/operation/operation.proto\x1a%yandex/cloud/backup/v1/resource.proto\x1a\x1dyandex/cloud/validation.proto\"U\n\x13ListArchivesRequest\x12\x13\n\tfolder_id\x18\x01 \x01(\tH\x00\x12\x1d\n\x13\x63ompute_instance_id\x18\x02 \x01(\tH\x00\x42\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"I\n\x14ListArchivesResponse\x12\x31\n\x08\x61rchives\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.backup.v1.Archive\"\xc5\x04\n\x12ListBackupsRequest\x12\x1d\n\x13\x63ompute_instance_id\x18\x01 \x01(\tH\x00\x12O\n\x07\x61rchive\x18\x02 \x01(\x0b\x32<.yandex.cloud.backup.v1.ListBackupsRequest.ArchiveParametersH\x00\x12\x13\n\tfolder_id\x18\x03 \x01(\tH\x00\x12T\n\x0finstance_policy\x18\x04 \x01(\x0b\x32\x39.yandex.cloud.backup.v1.ListBackupsRequest.InstancePolicyH\x00\x12\x15\n\x0bresource_id\x18\x06 \x01(\tH\x00\x12\x13\n\tpolicy_id\x18\x07 \x01(\tH\x00\x12\x10\n\x08order_by\x18\x05 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x08 \x01(\t\x12\x32\n\x04type\x18\t \x01(\x0e\x32$.yandex.cloud.backup.v1.ResourceType\x12\x1d\n\tpage_size\x18\n \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x0b \x01(\tB\t\x8a\xc8\x31\x05<=100\x1a\x46\n\x11\x41rchiveParameters\x12\x18\n\narchive_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x1a@\n\x0eInstancePolicy\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x11\n\tpolicy_id\x18\x02 \x01(\tB\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"_\n\x13ListBackupsResponse\x12/\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.backup.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"]\n\x10ListFilesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tsource_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x00\"F\n\x11ListFilesResponse\x12\x31\n\x05\x66iles\x18\x01 \x03(\x0b\x32\".yandex.cloud.backup.v1.BackupFile\"D\n\x10GetBackupRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"Z\n\x14StartRecoveryRequest\x12)\n\x13\x63ompute_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\tbackup_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"l\n\x15StartRecoveryMetadata\x12\x1b\n\x13progress_percentage\x18\x01 \x01(\x01\x12\x15\n\rsrc_backup_id\x18\x02 \x01(\t\x12\x1f\n\x17\x64st_compute_instance_id\x18\x03 \x01(\t\"\x14\n\x12TargetPathOriginal\" \n\x10TargetPathCustom\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xfb\x02\n\x14\x46ilesRecoveryOptions\x12O\n\toverwrite\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.backup.v1.FilesRecoveryOptions.OverwriteB\x04\xe8\xc7\x31\x00\x12\x1e\n\x10reboot_if_needed\x18\x02 \x01(\x08\x42\x04\xe8\xc7\x31\x00\x12>\n\x08original\x18\x64 \x01(\x0b\x32*.yandex.cloud.backup.v1.TargetPathOriginalH\x00\x12:\n\x06\x63ustom\x18\x65 \x01(\x0b\x32(.yandex.cloud.backup.v1.TargetPathCustomH\x00\"b\n\tOverwrite\x12\x19\n\x15OVERWRITE_UNSPECIFIED\x10\x00\x12\x11\n\rOVERWRITE_ALL\x10\x01\x12\x13\n\x0fOVERWRITE_OLDER\x10\x02\x12\x12\n\x0eOVERWRITE_NONE\x10\x03\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01J\x04\x08\x03\x10\x64\"\xb5\x01\n\x19StartFilesRecoveryRequest\x12!\n\x13\x63ompute_instance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12@\n\x04opts\x18\x03 \x01(\x0b\x32,.yandex.cloud.backup.v1.FilesRecoveryOptionsB\x04\xe8\xc7\x31\x01\x12\x1a\n\nsource_ids\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\"\x91\x01\n\x1aStartFilesRecoveryMetadata\x12\x1b\n\x13progress_percentage\x18\x01 \x01(\x01\x12!\n\x13\x63ompute_instance_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\nsource_ids\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\"Y\n\x13\x44\x65leteBackupRequest\x12)\n\x13\x63ompute_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\tbackup_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"F\n\x14\x44\x65leteBackupMetadata\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x11\n\tbackup_id\x18\x02 \x01(\t\"\x95\x01\n\x14\x44\x65leteArchiveRequest\x12\x18\n\narchive_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x00\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x00\x8a\xc8\x31\x04<=50\x12!\n\x0binstance_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x00\x8a\xc8\x31\x04<=50\x12\x1f\n\tpolicy_id\x18\x04 \x01(\tB\x0c\xe8\xc7\x31\x00\x8a\xc8\x31\x04<=50\">\n\x15\x44\x65leteArchiveMetadata\x12\x12\n\narchive_id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t2\x92\n\n\rBackupService\x12{\n\x04List\x12*.yandex.cloud.backup.v1.ListBackupsRequest\x1a+.yandex.cloud.backup.v1.ListBackupsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/backup/v1/backups\x12\xa4\x01\n\x0cListArchives\x12+.yandex.cloud.backup.v1.ListArchivesRequest\x1a,.yandex.cloud.backup.v1.ListArchivesResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/backup/v1/backups/{compute_instance_id}/archives\x12\x8e\x01\n\tListFiles\x12(.yandex.cloud.backup.v1.ListFilesRequest\x1a).yandex.cloud.backup.v1.ListFilesResponse\",\x82\xd3\xe4\x93\x02&\x12$/backup/v1/backups/{backup_id}/files\x12w\n\x03Get\x12(.yandex.cloud.backup.v1.GetBackupRequest\x1a\x1e.yandex.cloud.backup.v1.Backup\"&\x82\xd3\xe4\x93\x02 \x12\x1e/backup/v1/backups/{backup_id}\x12\xcb\x01\n\rStartRecovery\x12,.yandex.cloud.backup.v1.StartRecoveryRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*.\n\x15StartRecoveryMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31\",/backup/v1/backups/{backup_id}:startRecovery:\x01*\x12\xa3\x01\n\x12StartFilesRecovery\x12\x31.yandex.cloud.backup.v1.StartFilesRecoveryRequest\x1a!.yandex.cloud.operation.Operation\"7\xb2\xd2*3\n\x1aStartFilesRecoveryMetadata\x12\x15google.protobuf.Empty\x12\xc7\x01\n\x06\x44\x65lete\x12+.yandex.cloud.backup.v1.DeleteBackupRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*-\n\x14\x44\x65leteBackupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/backup/v1/backups/{compute_instance_id}/{backup_id}\x12\x94\x01\n\rDeleteArchive\x12,.yandex.cloud.backup.v1.DeleteArchiveRequest\x1a!.yandex.cloud.operation.Operation\"2\xb2\xd2*.\n\x15\x44\x65leteArchiveMetadata\x12\x15google.protobuf.EmptyB_\n\x1ayandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.backup.v1.backup_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backup'
  _globals['_LISTARCHIVESREQUEST'].oneofs_by_name['id']._loaded_options = None
  _globals['_LISTARCHIVESREQUEST'].oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _globals['_LISTBACKUPSREQUEST_ARCHIVEPARAMETERS'].fields_by_name['archive_id']._loaded_options = None
  _globals['_LISTBACKUPSREQUEST_ARCHIVEPARAMETERS'].fields_by_name['archive_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBACKUPSREQUEST_ARCHIVEPARAMETERS'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTBACKUPSREQUEST_ARCHIVEPARAMETERS'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBACKUPSREQUEST'].oneofs_by_name['id']._loaded_options = None
  _globals['_LISTBACKUPSREQUEST'].oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBACKUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTFILESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTFILESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTFILESREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_LISTFILESREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTFILESREQUEST'].fields_by_name['source_id']._loaded_options = None
  _globals['_LISTFILESREQUEST'].fields_by_name['source_id']._serialized_options = b'\350\3071\000'
  _globals['_GETBACKUPREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_GETBACKUPREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_GETBACKUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETBACKUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTRECOVERYREQUEST'].fields_by_name['compute_instance_id']._loaded_options = None
  _globals['_STARTRECOVERYREQUEST'].fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTRECOVERYREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_STARTRECOVERYREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_FILESRECOVERYOPTIONS'].oneofs_by_name['type']._loaded_options = None
  _globals['_FILESRECOVERYOPTIONS'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_FILESRECOVERYOPTIONS'].fields_by_name['overwrite']._loaded_options = None
  _globals['_FILESRECOVERYOPTIONS'].fields_by_name['overwrite']._serialized_options = b'\350\3071\000'
  _globals['_FILESRECOVERYOPTIONS'].fields_by_name['reboot_if_needed']._loaded_options = None
  _globals['_FILESRECOVERYOPTIONS'].fields_by_name['reboot_if_needed']._serialized_options = b'\350\3071\000'
  _globals['_STARTFILESRECOVERYREQUEST'].fields_by_name['compute_instance_id']._loaded_options = None
  _globals['_STARTFILESRECOVERYREQUEST'].fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTFILESRECOVERYREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_STARTFILESRECOVERYREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTFILESRECOVERYREQUEST'].fields_by_name['opts']._loaded_options = None
  _globals['_STARTFILESRECOVERYREQUEST'].fields_by_name['opts']._serialized_options = b'\350\3071\001'
  _globals['_STARTFILESRECOVERYREQUEST'].fields_by_name['source_ids']._loaded_options = None
  _globals['_STARTFILESRECOVERYREQUEST'].fields_by_name['source_ids']._serialized_options = b'\202\3101\002>0'
  _globals['_STARTFILESRECOVERYMETADATA'].fields_by_name['compute_instance_id']._loaded_options = None
  _globals['_STARTFILESRECOVERYMETADATA'].fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTFILESRECOVERYMETADATA'].fields_by_name['backup_id']._loaded_options = None
  _globals['_STARTFILESRECOVERYMETADATA'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTFILESRECOVERYMETADATA'].fields_by_name['source_ids']._loaded_options = None
  _globals['_STARTFILESRECOVERYMETADATA'].fields_by_name['source_ids']._serialized_options = b'\202\3101\002>0'
  _globals['_DELETEBACKUPREQUEST'].fields_by_name['compute_instance_id']._loaded_options = None
  _globals['_DELETEBACKUPREQUEST'].fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBACKUPREQUEST'].fields_by_name['backup_id']._loaded_options = None
  _globals['_DELETEBACKUPREQUEST'].fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEARCHIVEREQUEST'].fields_by_name['archive_id']._loaded_options = None
  _globals['_DELETEARCHIVEREQUEST'].fields_by_name['archive_id']._serialized_options = b'\350\3071\000'
  _globals['_DELETEARCHIVEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_DELETEARCHIVEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\000\212\3101\004<=50'
  _globals['_DELETEARCHIVEREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_DELETEARCHIVEREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\000\212\3101\004<=50'
  _globals['_DELETEARCHIVEREQUEST'].fields_by_name['policy_id']._loaded_options = None
  _globals['_DELETEARCHIVEREQUEST'].fields_by_name['policy_id']._serialized_options = b'\350\3071\000\212\3101\004<=50'
  _globals['_BACKUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\024\022\022/backup/v1/backups'
  _globals['_BACKUPSERVICE'].methods_by_name['ListArchives']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['ListArchives']._serialized_options = b'\202\323\344\223\0023\0221/backup/v1/backups/{compute_instance_id}/archives'
  _globals['_BACKUPSERVICE'].methods_by_name['ListFiles']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['ListFiles']._serialized_options = b'\202\323\344\223\002&\022$/backup/v1/backups/{backup_id}/files'
  _globals['_BACKUPSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002 \022\036/backup/v1/backups/{backup_id}'
  _globals['_BACKUPSERVICE'].methods_by_name['StartRecovery']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['StartRecovery']._serialized_options = b'\262\322*.\n\025StartRecoveryMetadata\022\025google.protobuf.Empty\202\323\344\223\0021\",/backup/v1/backups/{backup_id}:startRecovery:\001*'
  _globals['_BACKUPSERVICE'].methods_by_name['StartFilesRecovery']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['StartFilesRecovery']._serialized_options = b'\262\322*3\n\032StartFilesRecoveryMetadata\022\025google.protobuf.Empty'
  _globals['_BACKUPSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteBackupMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/backup/v1/backups/{compute_instance_id}/{backup_id}'
  _globals['_BACKUPSERVICE'].methods_by_name['DeleteArchive']._loaded_options = None
  _globals['_BACKUPSERVICE'].methods_by_name['DeleteArchive']._serialized_options = b'\262\322*.\n\025DeleteArchiveMetadata\022\025google.protobuf.Empty'
  _globals['_LISTARCHIVESREQUEST']._serialized_start=282
  _globals['_LISTARCHIVESREQUEST']._serialized_end=367
  _globals['_LISTARCHIVESRESPONSE']._serialized_start=369
  _globals['_LISTARCHIVESRESPONSE']._serialized_end=442
  _globals['_LISTBACKUPSREQUEST']._serialized_start=445
  _globals['_LISTBACKUPSREQUEST']._serialized_end=1026
  _globals['_LISTBACKUPSREQUEST_ARCHIVEPARAMETERS']._serialized_start=878
  _globals['_LISTBACKUPSREQUEST_ARCHIVEPARAMETERS']._serialized_end=948
  _globals['_LISTBACKUPSREQUEST_INSTANCEPOLICY']._serialized_start=950
  _globals['_LISTBACKUPSREQUEST_INSTANCEPOLICY']._serialized_end=1014
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=1028
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=1123
  _globals['_LISTFILESREQUEST']._serialized_start=1125
  _globals['_LISTFILESREQUEST']._serialized_end=1218
  _globals['_LISTFILESRESPONSE']._serialized_start=1220
  _globals['_LISTFILESRESPONSE']._serialized_end=1290
  _globals['_GETBACKUPREQUEST']._serialized_start=1292
  _globals['_GETBACKUPREQUEST']._serialized_end=1360
  _globals['_STARTRECOVERYREQUEST']._serialized_start=1362
  _globals['_STARTRECOVERYREQUEST']._serialized_end=1452
  _globals['_STARTRECOVERYMETADATA']._serialized_start=1454
  _globals['_STARTRECOVERYMETADATA']._serialized_end=1562
  _globals['_TARGETPATHORIGINAL']._serialized_start=1564
  _globals['_TARGETPATHORIGINAL']._serialized_end=1584
  _globals['_TARGETPATHCUSTOM']._serialized_start=1586
  _globals['_TARGETPATHCUSTOM']._serialized_end=1618
  _globals['_FILESRECOVERYOPTIONS']._serialized_start=1621
  _globals['_FILESRECOVERYOPTIONS']._serialized_end=2000
  _globals['_FILESRECOVERYOPTIONS_OVERWRITE']._serialized_start=1882
  _globals['_FILESRECOVERYOPTIONS_OVERWRITE']._serialized_end=1980
  _globals['_STARTFILESRECOVERYREQUEST']._serialized_start=2003
  _globals['_STARTFILESRECOVERYREQUEST']._serialized_end=2184
  _globals['_STARTFILESRECOVERYMETADATA']._serialized_start=2187
  _globals['_STARTFILESRECOVERYMETADATA']._serialized_end=2332
  _globals['_DELETEBACKUPREQUEST']._serialized_start=2334
  _globals['_DELETEBACKUPREQUEST']._serialized_end=2423
  _globals['_DELETEBACKUPMETADATA']._serialized_start=2425
  _globals['_DELETEBACKUPMETADATA']._serialized_end=2495
  _globals['_DELETEARCHIVEREQUEST']._serialized_start=2498
  _globals['_DELETEARCHIVEREQUEST']._serialized_end=2647
  _globals['_DELETEARCHIVEMETADATA']._serialized_start=2649
  _globals['_DELETEARCHIVEMETADATA']._serialized_end=2711
  _globals['_BACKUPSERVICE']._serialized_start=2714
  _globals['_BACKUPSERVICE']._serialized_end=4012
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/triggers/v1/trigger.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/triggers/v1/trigger.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/serverless/triggers/v1/trigger.proto\x12#yandex.cloud.serverless.triggers.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\xbe.\n\x07Trigger\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x04name\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04\x33-63\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-256\x12H\n\x06labels\x18\x06 \x03(\x0b\x32\x38.yandex.cloud.serverless.triggers.v1.Trigger.LabelsEntry\x12\x45\n\x04rule\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.serverless.triggers.v1.Trigger.RuleB\x04\xe8\xc7\x31\x01\x12\x43\n\x06status\x18\t \x01(\x0e\x32\x33.yandex.cloud.serverless.triggers.v1.Trigger.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xfc\x06\n\x04Rule\x12\x43\n\x05timer\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.Trigger.TimerH\x00\x12R\n\rmessage_queue\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.serverless.triggers.v1.Trigger.MessageQueueH\x00\x12N\n\x0biot_message\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.Trigger.IoTMessageH\x00\x12[\n\x12iot_broker_message\x18\x0e \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessageH\x00\x12T\n\x0eobject_storage\x18\x05 \x01(\x0b\x32:.yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorageH\x00\x12\\\n\x12\x63ontainer_registry\x18\x06 \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistryH\x00\x12L\n\ncloud_logs\x18\t \x01(\x0b\x32\x36.yandex.cloud.serverless.triggers.v1.Trigger.CloudLogsH\x00\x12G\n\x07logging\x18\n \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.Trigger.LoggingH\x00\x12L\n\x0e\x62illing_budget\x18\x0b \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BillingBudgetH\x00\x12\x46\n\x0b\x64\x61ta_stream\x18\x0c \x01(\x0b\x32/.yandex.cloud.serverless.triggers.v1.DataStreamH\x00\x12\x39\n\x04mail\x18\r \x01(\x0b\x32).yandex.cloud.serverless.triggers.v1.MailH\x00\x42\x0c\n\x04rule\x12\x04\xc0\xc1\x31\x01J\x04\x08\x07\x10\t\x1a\xed\x03\n\x05Timer\x12&\n\x0f\x63ron_expression\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\x1b\n\x07payload\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=4096\x12R\n\x0finvoke_function\x18\x65 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.InvokeFunctionOnceH\x00\x12\x62\n\x1ainvoke_function_with_retry\x18g \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12\x64\n\x1binvoke_container_with_retry\x18h \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18i \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x66\x10gJ\x04\x08\x03\x10\x65\x1a\x91\x04\n\x0cMessageQueue\x12\x16\n\x08queue_id\x18\x0b \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12P\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettingsB\x04\xe8\xc7\x31\x01\x12@\n\x12visibility_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=12h\x12R\n\x0finvoke_function\x18\x65 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.InvokeFunctionOnceH\x00\x12T\n\x10invoke_container\x18\x66 \x01(\x0b\x32\x38.yandex.cloud.serverless.triggers.v1.InvokeContainerOnceH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18g \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x0c\x10\x65J\x04\x08\x06\x10\x0b\x1a\xcb\x03\n\nIoTMessage\x12\x19\n\x0bregistry_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x12\n\nmqtt_topic\x18\x03 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18g \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x05\x10\x65\x1a\xbc\x03\n\x10IoTBrokerMessage\x12\x17\n\tbroker_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\nmqtt_topic\x18\x02 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18g \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x04\x10\x65\x1a\xa6\x04\n\rObjectStorage\x12_\n\nevent_type\x18\x03 \x03(\x0e\x32\x43.yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorageEventTypeB\x06\x82\xc8\x31\x02>0\x12\x11\n\tbucket_id\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x06 \x01(\t\x12\x0e\n\x06suffix\x18\x07 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18g \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\t\x10\x65J\x04\x08\x05\x10\x06\x1a\xab\x04\n\x11\x43ontainerRegistry\x12\x63\n\nevent_type\x18\x03 \x03(\x0e\x32G.yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistryEventTypeB\x06\x82\xc8\x31\x02>0\x12\x13\n\x0bregistry_id\x18\x04 \x01(\t\x12\x12\n\nimage_name\x18\x05 \x01(\t\x12\x0b\n\x03tag\x18\x06 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x07 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18g \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x08\x10\x65\x1a\xc6\x02\n\tCloudLogs\x12\x14\n\x0clog_group_id\x18\x01 \x03(\t\x12Y\n\x0e\x62\x61tch_settings\x18\x02 \x01(\x0b\x32;.yandex.cloud.serverless.triggers.v1.CloudLogsBatchSettingsB\x04\xe8\xc7\x31\x01\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x03\x10\x65\x1a\xc5\x05\n\x07Logging\x12\x1e\n\x0clog_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12@\n\rresource_type\x18\x03 \x03(\tB)\xf2\xc7\x31\x1c[a-zA-Z][-a-zA-Z0-9_.]{1,62}\x82\xc8\x31\x05<=100\x12>\n\x0bresource_id\x18\x04 \x03(\tB)\xf2\xc7\x31\x1c[a-zA-Z][-a-zA-Z0-9_.]{1,62}\x82\xc8\x31\x05<=100\x12?\n\x0bstream_name\x18\x07 \x03(\tB*\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x82\xc8\x31\x05<=100\x12\x41\n\x06levels\x18\x05 \x03(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\x08\x82\xc8\x31\x04<=10\x12W\n\x0e\x62\x61tch_settings\x18\x06 \x01(\x0b\x32\x39.yandex.cloud.serverless.triggers.v1.LoggingBatchSettingsB\x04\xe8\xc7\x31\x01\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18h \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x08\x10\x65J\x04\x08\x66\x10gJ\x04\x08\x02\x10\x03\"\xca\x01\n\x16ObjectStorageEventType\x12)\n%OBJECT_STORAGE_EVENT_TYPE_UNSPECIFIED\x10\x00\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_CREATE_OBJECT\x10\x01\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_UPDATE_OBJECT\x10\x02\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_DELETE_OBJECT\x10\x03\"\x93\x02\n\x1a\x43ontainerRegistryEventType\x12-\n)CONTAINER_REGISTRY_EVENT_TYPE_UNSPECIFIED\x10\x00\x12.\n*CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE\x10\x01\x12.\n*CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE\x10\x02\x12\x32\n.CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE_TAG\x10\x03\x12\x32\n.CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE_TAG\x10\x04\"8\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\n\n\x06PAUSED\x10\x02J\x04\x08\x07\x10\x08\"i\n\x12InvokeFunctionOnce\x12!\n\x0b\x66unction_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x0c\x66unction_tag\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x03 \x01(\t\"\x8b\x02\n\x17InvokeFunctionWithRetry\x12!\n\x0b\x66unction_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x0c\x66unction_tag\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x03 \x01(\t\x12J\n\x0eretry_settings\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.RetrySettings\x12O\n\x11\x64\x65\x61\x64_letter_queue\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.PutQueueMessage\"i\n\x13InvokeContainerOnce\x12\"\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\"\x8b\x02\n\x18InvokeContainerWithRetry\x12\"\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12J\n\x0eretry_settings\x18\x05 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.RetrySettings\x12O\n\x11\x64\x65\x61\x64_letter_queue\x18\x06 \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.PutQueueMessageJ\x04\x08\x02\x10\x03\"{\n\x19GatewayWebsocketBroadcast\x12 \n\ngateway_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"S\n\x0fPutQueueMessage\x12\x10\n\x08queue_id\x18\x0b \x01(\t\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x03\x10\x0b\"Z\n\rBatchSettings\x12\x18\n\x04size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12/\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\"g\n\x16\x43loudLogsBatchSettings\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"f\n\x14LoggingBatchSettings\x12\x18\n\x04size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x31-1000\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"m\n\rRetrySettings\x12\x1f\n\x0eretry_attempts\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03\x31-5\x12;\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xe8\xc7\x31\x01\xfa\xc7\x31\x06\x31\x30s-1m\"\x8d\x03\n\rBillingBudget\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\tbudget_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18h \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x66\x10gJ\x04\x08\x03\x10\x65\"j\n\x17\x44\x61taStreamBatchSettings\x12\x19\n\x04size\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65536\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"\xe9\x03\n\nDataStream\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0e\n\x06stream\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12T\n\x0e\x62\x61tch_settings\x18\x05 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.DataStreamBatchSettings\x12W\n\x0finvoke_function\x18\r \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x0f \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18\x10 \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x0e\x10\x0fJ\x04\x08\x06\x10\r\"v\n\x1bObjectStorageBucketSettings\x12-\n\tbucket_id\x18\x01 \x01(\tB\x1a\xf2\xc7\x31\x0e[-.0-9a-zA-Z]*\x8a\xc8\x31\x04\x33-63\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xf6\x03\n\x04Mail\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12\\\n\x12\x61ttachments_bucket\x18\x04 \x01(\x0b\x32@.yandex.cloud.serverless.triggers.v1.ObjectStorageBucketSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x12\x65\n\x1bgateway_websocket_broadcast\x18h \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.GatewayWebsocketBroadcastH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x04\x08\x66\x10gJ\x04\x08\x05\x10\x65*\xe2\x01\n\x0bTriggerType\x12\x1c\n\x18TRIGGER_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05TIMER\x10\x02\x12\x11\n\rMESSAGE_QUEUE\x10\x03\x12\x0f\n\x0bIOT_MESSAGE\x10\x04\x12\x16\n\x12IOT_BROKER_MESSAGE\x10\x0c\x12\x12\n\x0eOBJECT_STORAGE\x10\x05\x12\x16\n\x12\x43ONTAINER_REGISTRY\x10\x06\x12\x0e\n\nCLOUD_LOGS\x10\x07\x12\x0b\n\x07LOGGING\x10\x08\x12\x12\n\x0e\x42ILLING_BUDGET\x10\t\x12\x07\n\x03YDS\x10\n\x12\x08\n\x04MAIL\x10\x0b\x42{\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.triggers.v1.trigger_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggers'
  _globals['_TRIGGER_LABELSENTRY']._loaded_options = None
  _globals['_TRIGGER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_TRIGGER_RULE'].oneofs_by_name['rule']._loaded_options = None
  _globals['_TRIGGER_RULE'].oneofs_by_name['rule']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_TIMER'].oneofs_by_name['action']._loaded_options = None
  _globals['_TRIGGER_TIMER'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_TIMER'].fields_by_name['cron_expression']._loaded_options = None
  _globals['_TRIGGER_TIMER'].fields_by_name['cron_expression']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_TRIGGER_TIMER'].fields_by_name['payload']._loaded_options = None
  _globals['_TRIGGER_TIMER'].fields_by_name['payload']._serialized_options = b'\212\3101\006<=4096'
  _globals['_TRIGGER_MESSAGEQUEUE'].oneofs_by_name['action']._loaded_options = None
  _globals['_TRIGGER_MESSAGEQUEUE'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_MESSAGEQUEUE'].fields_by_name['queue_id']._loaded_options = None
  _globals['_TRIGGER_MESSAGEQUEUE'].fields_by_name['queue_id']._serialized_options = b'\350\3071\001'
  _globals['_TRIGGER_MESSAGEQUEUE'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_TRIGGER_MESSAGEQUEUE'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRIGGER_MESSAGEQUEUE'].fields_by_name['batch_settings']._loaded_options = None
  _globals['_TRIGGER_MESSAGEQUEUE'].fields_by_name['batch_settings']._serialized_options = b'\350\3071\001'
  _globals['_TRIGGER_MESSAGEQUEUE'].fields_by_name['visibility_timeout']._loaded_options = None
  _globals['_TRIGGER_MESSAGEQUEUE'].fields_by_name['visibility_timeout']._serialized_options = b'\372\3071\005<=12h'
  _globals['_TRIGGER_IOTMESSAGE'].oneofs_by_name['action']._loaded_options = None
  _globals['_TRIGGER_IOTMESSAGE'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_IOTMESSAGE'].fields_by_name['registry_id']._loaded_options = None
  _globals['_TRIGGER_IOTMESSAGE'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001'
  _globals['_TRIGGER_IOTBROKERMESSAGE'].oneofs_by_name['action']._loaded_options = None
  _globals['_TRIGGER_IOTBROKERMESSAGE'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_IOTBROKERMESSAGE'].fields_by_name['broker_id']._loaded_options = None
  _globals['_TRIGGER_IOTBROKERMESSAGE'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001'
  _globals['_TRIGGER_OBJECTSTORAGE'].oneofs_by_name['action']._loaded_options = None
  _globals['_TRIGGER_OBJECTSTORAGE'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_OBJECTSTORAGE'].fields_by_name['event_type']._loaded_options = None
  _globals['_TRIGGER_OBJECTSTORAGE'].fields_by_name['event_type']._serialized_options = b'\202\3101\002>0'
  _globals['_TRIGGER_CONTAINERREGISTRY'].oneofs_by_name['action']._loaded_options = None
  _globals['_TRIGGER_CONTAINERREGISTRY'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_CONTAINERREGISTRY'].fields_by_name['event_type']._loaded_options = None
  _globals['_TRIGGER_CONTAINERREGISTRY'].fields_by_name['event_type']._serialized_options = b'\202\3101\002>0'
  _globals['_TRIGGER_CLOUDLOGS'].oneofs_by_name['action']._loaded_options = None
  _globals['_TRIGGER_CLOUDLOGS'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_CLOUDLOGS'].fields_by_name['batch_settings']._loaded_options = None
  _globals['_TRIGGER_CLOUDLOGS'].fields_by_name['batch_settings']._serialized_options = b'\350\3071\001'
  _globals['_TRIGGER_LOGGING'].oneofs_by_name['action']._loaded_options = None
  _globals['_TRIGGER_LOGGING'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGER_LOGGING'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_TRIGGER_LOGGING'].fields_by_name['log_group_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_TRIGGER_LOGGING'].fields_by_name['resource_type']._loaded_options = None
  _globals['_TRIGGER_LOGGING'].fields_by_name['resource_type']._serialized_options = b'\362\3071\034[a-zA-Z][-a-zA-Z0-9_.]{1,62}\202\3101\005<=100'
  _globals['_TRIGGER_LOGGING'].fields_by_name['resource_id']._loaded_options = None
  _globals['_TRIGGER_LOGGING'].fields_by_name['resource_id']._serialized_options = b'\362\3071\034[a-zA-Z][-a-zA-Z0-9_.]{1,62}\202\3101\005<=100'
  _globals['_TRIGGER_LOGGING'].fields_by_name['stream_name']._loaded_options = None
  _globals['_TRIGGER_LOGGING'].fields_by_name['stream_name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]\202\3101\005<=100'
  _globals['_TRIGGER_LOGGING'].fields_by_name['levels']._loaded_options = None
  _globals['_TRIGGER_LOGGING'].fields_by_name['levels']._serialized_options = b'\202\3101\004<=10'
  _globals['_TRIGGER_LOGGING'].fields_by_name['batch_settings']._loaded_options = None
  _globals['_TRIGGER_LOGGING'].fields_by_name['batch_settings']._serialized_options = b'\350\3071\001'
  _globals['_TRIGGER'].fields_by_name['folder_id']._loaded_options = None
  _globals['_TRIGGER'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRIGGER'].fields_by_name['name']._loaded_options = None
  _globals['_TRIGGER'].fields_by_name['name']._serialized_options = b'\212\3101\0043-63'
  _globals['_TRIGGER'].fields_by_name['description']._loaded_options = None
  _globals['_TRIGGER'].fields_by_name['description']._serialized_options = b'\212\3101\0050-256'
  _globals['_TRIGGER'].fields_by_name['rule']._loaded_options = None
  _globals['_TRIGGER'].fields_by_name['rule']._serialized_options = b'\350\3071\001'
  _globals['_INVOKEFUNCTIONONCE'].fields_by_name['function_id']._loaded_options = None
  _globals['_INVOKEFUNCTIONONCE'].fields_by_name['function_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_INVOKEFUNCTIONWITHRETRY'].fields_by_name['function_id']._loaded_options = None
  _globals['_INVOKEFUNCTIONWITHRETRY'].fields_by_name['function_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_INVOKECONTAINERONCE'].fields_by_name['container_id']._loaded_options = None
  _globals['_INVOKECONTAINERONCE'].fields_by_name['container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_INVOKECONTAINERWITHRETRY'].fields_by_name['container_id']._loaded_options = None
  _globals['_INVOKECONTAINERWITHRETRY'].fields_by_name['container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GATEWAYWEBSOCKETBROADCAST'].fields_by_name['gateway_id']._loaded_options = None
  _globals['_GATEWAYWEBSOCKETBROADCAST'].fields_by_name['gateway_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GATEWAYWEBSOCKETBROADCAST'].fields_by_name['path']._loaded_options = None
  _globals['_GATEWAYWEBSOCKETBROADCAST'].fields_by_name['path']._serialized_options = b'\350\3071\001'
  _globals['_GATEWAYWEBSOCKETBROADCAST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_GATEWAYWEBSOCKETBROADCAST'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PUTQUEUEMESSAGE'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_PUTQUEUEMESSAGE'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHSETTINGS'].fields_by_name['size']._loaded_options = None
  _globals['_BATCHSETTINGS'].fields_by_name['size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_BATCHSETTINGS'].fields_by_name['cutoff']._loaded_options = None
  _globals['_BATCHSETTINGS'].fields_by_name['cutoff']._serialized_options = b'\350\3071\001'
  _globals['_CLOUDLOGSBATCHSETTINGS'].fields_by_name['size']._loaded_options = None
  _globals['_CLOUDLOGSBATCHSETTINGS'].fields_by_name['size']._serialized_options = b'\372\3071\0050-100'
  _globals['_CLOUDLOGSBATCHSETTINGS'].fields_by_name['cutoff']._loaded_options = None
  _globals['_CLOUDLOGSBATCHSETTINGS'].fields_by_name['cutoff']._serialized_options = b'\372\3071\0051s-1m'
  _globals['_LOGGINGBATCHSETTINGS'].fields_by_name['size']._loaded_options = None
  _globals['_LOGGINGBATCHSETTINGS'].fields_by_name['size']._serialized_options = b'\372\3071\0061-1000'
  _globals['_LOGGINGBATCHSETTINGS'].fields_by_name['cutoff']._loaded_options = None
  _globals['_LOGGINGBATCHSETTINGS'].fields_by_name['cutoff']._serialized_options = b'\372\3071\0051s-1m'
  _globals['_RETRYSETTINGS'].fields_by_name['retry_attempts']._loaded_options = None
  _globals['_RETRYSETTINGS'].fields_by_name['retry_attempts']._serialized_options = b'\372\3071\0031-5'
  _globals['_RETRYSETTINGS'].fields_by_name['interval']._loaded_options = None
  _globals['_RETRYSETTINGS'].fields_by_name['interval']._serialized_options = b'\350\3071\001\372\3071\00610s-1m'
  _globals['_BILLINGBUDGET'].oneofs_by_name['action']._loaded_options = None
  _globals['_BILLINGBUDGET'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_BILLINGBUDGET'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_BILLINGBUDGET'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BILLINGBUDGET'].fields_by_name['budget_id']._loaded_options = None
  _globals['_BILLINGBUDGET'].fields_by_name['budget_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DATASTREAMBATCHSETTINGS'].fields_by_name['size']._loaded_options = None
  _globals['_DATASTREAMBATCHSETTINGS'].fields_by_name['size']._serialized_options = b'\372\3071\0071-65536'
  _globals['_DATASTREAMBATCHSETTINGS'].fields_by_name['cutoff']._loaded_options = None
  _globals['_DATASTREAMBATCHSETTINGS'].fields_by_name['cutoff']._serialized_options = b'\372\3071\0051s-1m'
  _globals['_DATASTREAM'].oneofs_by_name['action']._loaded_options = None
  _globals['_DATASTREAM'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_OBJECTSTORAGEBUCKETSETTINGS'].fields_by_name['bucket_id']._loaded_options = None
  _globals['_OBJECTSTORAGEBUCKETSETTINGS'].fields_by_name['bucket_id']._serialized_options = b'\362\3071\016[-.0-9a-zA-Z]*\212\3101\0043-63'
  _globals['_OBJECTSTORAGEBUCKETSETTINGS'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_OBJECTSTORAGEBUCKETSETTINGS'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MAIL'].oneofs_by_name['action']._loaded_options = None
  _globals['_MAIL'].oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGERTYPE']._serialized_start=9182
  _globals['_TRIGGERTYPE']._serialized_end=9408
  _globals['_TRIGGER']._serialized_start=228
  _globals['_TRIGGER']._serialized_end=6178
  _globals['_TRIGGER_LABELSENTRY']._serialized_start=602
  _globals['_TRIGGER_LABELSENTRY']._serialized_end=647
  _globals['_TRIGGER_RULE']._serialized_start=650
  _globals['_TRIGGER_RULE']._serialized_end=1542
  _globals['_TRIGGER_TIMER']._serialized_start=1545
  _globals['_TRIGGER_TIMER']._serialized_end=2038
  _globals['_TRIGGER_MESSAGEQUEUE']._serialized_start=2041
  _globals['_TRIGGER_MESSAGEQUEUE']._serialized_end=2570
  _globals['_TRIGGER_IOTMESSAGE']._serialized_start=2573
  _globals['_TRIGGER_IOTMESSAGE']._serialized_end=3032
  _globals['_TRIGGER_IOTBROKERMESSAGE']._serialized_start=3035
  _globals['_TRIGGER_IOTBROKERMESSAGE']._serialized_end=3479
  _globals['_TRIGGER_OBJECTSTORAGE']._serialized_start=3482
  _globals['_TRIGGER_OBJECTSTORAGE']._serialized_end=4032
  _globals['_TRIGGER_CONTAINERREGISTRY']._serialized_start=4035
  _globals['_TRIGGER_CONTAINERREGISTRY']._serialized_end=4590
  _globals['_TRIGGER_CLOUDLOGS']._serialized_start=4593
  _globals['_TRIGGER_CLOUDLOGS']._serialized_end=4919
  _globals['_TRIGGER_LOGGING']._serialized_start=4922
  _globals['_TRIGGER_LOGGING']._serialized_end=5631
  _globals['_TRIGGER_OBJECTSTORAGEEVENTTYPE']._serialized_start=5634
  _globals['_TRIGGER_OBJECTSTORAGEEVENTTYPE']._serialized_end=5836
  _globals['_TRIGGER_CONTAINERREGISTRYEVENTTYPE']._serialized_start=5839
  _globals['_TRIGGER_CONTAINERREGISTRYEVENTTYPE']._serialized_end=6114
  _globals['_TRIGGER_STATUS']._serialized_start=6116
  _globals['_TRIGGER_STATUS']._serialized_end=6172
  _globals['_INVOKEFUNCTIONONCE']._serialized_start=6180
  _globals['_INVOKEFUNCTIONONCE']._serialized_end=6285
  _globals['_INVOKEFUNCTIONWITHRETRY']._serialized_start=6288
  _globals['_INVOKEFUNCTIONWITHRETRY']._serialized_end=6555
  _globals['_INVOKECONTAINERONCE']._serialized_start=6557
  _globals['_INVOKECONTAINERONCE']._serialized_end=6662
  _globals['_INVOKECONTAINERWITHRETRY']._serialized_start=6665
  _globals['_INVOKECONTAINERWITHRETRY']._serialized_end=6932
  _globals['_GATEWAYWEBSOCKETBROADCAST']._serialized_start=6934
  _globals['_GATEWAYWEBSOCKETBROADCAST']._serialized_end=7057
  _globals['_PUTQUEUEMESSAGE']._serialized_start=7059
  _globals['_PUTQUEUEMESSAGE']._serialized_end=7142
  _globals['_BATCHSETTINGS']._serialized_start=7144
  _globals['_BATCHSETTINGS']._serialized_end=7234
  _globals['_CLOUDLOGSBATCHSETTINGS']._serialized_start=7236
  _globals['_CLOUDLOGSBATCHSETTINGS']._serialized_end=7339
  _globals['_LOGGINGBATCHSETTINGS']._serialized_start=7341
  _globals['_LOGGINGBATCHSETTINGS']._serialized_end=7443
  _globals['_RETRYSETTINGS']._serialized_start=7445
  _globals['_RETRYSETTINGS']._serialized_end=7554
  _globals['_BILLINGBUDGET']._serialized_start=7557
  _globals['_BILLINGBUDGET']._serialized_end=7954
  _globals['_DATASTREAMBATCHSETTINGS']._serialized_start=7956
  _globals['_DATASTREAMBATCHSETTINGS']._serialized_end=8062
  _globals['_DATASTREAM']._serialized_start=8065
  _globals['_DATASTREAM']._serialized_end=8554
  _globals['_OBJECTSTORAGEBUCKETSETTINGS']._serialized_start=8556
  _globals['_OBJECTSTORAGEBUCKETSETTINGS']._serialized_end=8674
  _globals['_MAIL']._serialized_start=8677
  _globals['_MAIL']._serialized_end=9179
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HealthCheck(google.protobuf.message.Message):
    """A HealthCheck resource. For more information, see [Health check](/docs/network-load-balancer/concepts/health-check)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TcpOptions(google.protobuf.message.Message):
        """Configuration option for a TCP health check."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PORT_FIELD_NUMBER: builtins.int
        port: builtins.int
        """Port to use for TCP health checks."""
        def __init__(
            self,
            *,
            port: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["port", b"port"]) -> None: ...

    @typing.final
    class HttpOptions(google.protobuf.message.Message):
        """Configuration option for an HTTP health check."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PORT_FIELD_NUMBER: builtins.int
        PATH_FIELD_NUMBER: builtins.int
        port: builtins.int
        """Port to use for HTTP health checks."""
        path: builtins.str
        """URL path to set for health checking requests for every target in the target group. 
        For example `` /ping ``. The default path is `` / ``.
        """
        def __init__(
            self,
            *,
            port: builtins.int = ...,
            path: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["path", b"path", "port", b"port"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    TCP_OPTIONS_FIELD_NUMBER: builtins.int
    HTTP_OPTIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the health check. The name must be unique for each target group that attached to a single load balancer. 3-63 characters long."""
    unhealthy_threshold: builtins.int
    """Number of failed health checks before changing the status to `` UNHEALTHY ``. The default is 2."""
    healthy_threshold: builtins.int
    """Number of successful health checks required in order to set the `` HEALTHY `` status for the target. The default is 2."""
    @property
    def interval(self) -> google.protobuf.duration_pb2.Duration:
        """The interval between health checks. The default is 2 seconds."""

    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Timeout for a target to return a response for the health check. The default is 1 second."""

    @property
    def tcp_options(self) -> global___HealthCheck.TcpOptions:
        """Options for TCP health check."""

    @property
    def http_options(self) -> global___HealthCheck.HttpOptions:
        """Options for HTTP health check."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        interval: google.protobuf.duration_pb2.Duration | None = ...,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        unhealthy_threshold: builtins.int = ...,
        healthy_threshold: builtins.int = ...,
        tcp_options: global___HealthCheck.TcpOptions | None = ...,
        http_options: global___HealthCheck.HttpOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["http_options", b"http_options", "interval", b"interval", "options", b"options", "tcp_options", b"tcp_options", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["healthy_threshold", b"healthy_threshold", "http_options", b"http_options", "interval", b"interval", "name", b"name", "options", b"options", "tcp_options", b"tcp_options", "timeout", b"timeout", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["options", b"options"]) -> typing.Literal["tcp_options", "http_options"] | None: ...

global___HealthCheck = HealthCheck



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2
import yandex.cloud.marketplace.licensemanager.v1.instance_pb2
import yandex.cloud.marketplace.licensemanager.v1.user_info_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class InstanceServiceStub:
    """A set of methods for managing subscription instances."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2.GetInstanceRequest,
        yandex.cloud.marketplace.licensemanager.v1.instance_pb2.Instance,
    ]
    """Returns the specified subscription instance."""

    GetUserInfo: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2.GetUserInfoRequest,
        yandex.cloud.marketplace.licensemanager.v1.user_info_pb2.UserInfo,
    ]
    """Returns information about legal person (Russia only) who owns this subscription instance."""

class InstanceServiceAsyncStub:
    """A set of methods for managing subscription instances."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2.GetInstanceRequest,
        yandex.cloud.marketplace.licensemanager.v1.instance_pb2.Instance,
    ]
    """Returns the specified subscription instance."""

    GetUserInfo: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2.GetUserInfoRequest,
        yandex.cloud.marketplace.licensemanager.v1.user_info_pb2.UserInfo,
    ]
    """Returns information about legal person (Russia only) who owns this subscription instance."""

class InstanceServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing subscription instances."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2.GetInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.marketplace.licensemanager.v1.instance_pb2.Instance, collections.abc.Awaitable[yandex.cloud.marketplace.licensemanager.v1.instance_pb2.Instance]]:
        """Returns the specified subscription instance."""

    @abc.abstractmethod
    def GetUserInfo(
        self,
        request: yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2.GetUserInfoRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.marketplace.licensemanager.v1.user_info_pb2.UserInfo, collections.abc.Awaitable[yandex.cloud.marketplace.licensemanager.v1.user_info_pb2.UserInfo]]:
        """Returns information about legal person (Russia only) who owns this subscription instance."""

def add_InstanceServiceServicer_to_server(servicer: InstanceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
